@@ -646,26 +646,27 @@ Boolean labeltext(int keypressed, char *clientdata)
 	  eventmode = NORMAL_MODE;
       }
       else if (eventmode == CATTEXT_MODE) {
+	 objectptr libobj;
+	 stringpart *oldname;
 
-         /* set name of object to new string */
+	 /* Get the library object whose name matches the original string */
+	 oldname = get_original_string(curlabel);
+	 libobj = NameToObject(oldname->nextpart->data.string, NULL, FALSE);
+	 if (libobj != NULL) {
+
+	    /* set name of object to new string */
+
+	    strcpy(libobj->name, curlabel->string->nextpart->data.string);
 
-	 areastruct.save.y = curlabel->position.y + 100;
-	 areastruct.save.x = curlabel->position.x;
-	 select_element(OBJINST);
-	 if (areastruct.selects == 1) {  /* this should be true! */
-	    short *selptr = areastruct.selectlist + areastruct.selects - 1;
-	    objinstptr selobj = SELTOOBJINST(selptr);
-	    strcpy(selobj->thisobject->name, curlabel->string->nextpart->data.string);
 	    /* If checkname() alters the name, it has to be copied back to */
 	    /* the catalog label for the object.			   */
 
-	    if (checkname(selobj->thisobject)) {
+	    if (checkname(libobj)) {
 	       undrawtext(curlabel);
 	       curlabel->string->nextpart->data.string = (char *)realloc(
 			curlabel->string->nextpart->data.string,
 		  	(strlen(_STR) + 1) * sizeof(char));
-	       strcpy(curlabel->string->nextpart->data.string,
-			selobj->thisobject->name);
+	       strcpy(curlabel->string->nextpart->data.string, libobj->name);
                XcSetFunction(GXcopy);
 	       redrawtext(curlabel);
 	    }
