@@ -135,6 +135,9 @@ extern Tcl_HashTable XcTagTable;
 /* Initialization procedure for Tcl/Tk				*/
 /*--------------------------------------------------------------*/
 
+#ifdef _MSC_VER
+__declspec(dllexport)
+#endif
 int
 Xcircuit_Init(Tcl_Interp *interp)
 {
@@ -197,11 +200,11 @@ Xcircuit_Init(Tcl_Interp *interp)
 
    Tcl_SetVar(interp, "XCIRCUIT_LIB_DIR", tmp_s, TCL_GLOBAL_ONLY);
 
-   /* Set $CAD_HOME as a Tcl variable */
+   /* Set $CAD_ROOT as a Tcl variable */
 
-   cadhome = getenv("CAD_HOME");
+   cadhome = getenv("CAD_ROOT");
    if (cadhome == NULL) cadhome = CAD_DIR;
-   Tcl_SetVar(interp, "CAD_HOME", cadhome, TCL_GLOBAL_ONLY);
+   Tcl_SetVar(interp, "CAD_ROOT", cadhome, TCL_GLOBAL_ONLY);
 
    /* Set $XCIRCUIT_VERSION and $XCIRCUIT_REVISION as Tcl variables */
 
